@@ -2,6 +2,7 @@ from . import base
 from . import antique
 from . import aquaint
 from . import beir
+from . import c4
 from . import car
 from . import clinicaltrials
 from . import clirmatrix
@@ -15,6 +16,8 @@ from . import gov
 from . import gov2
 from . import highwire
 from . import medline
+from . import mmarco
+from . import mr_tydi
 from . import msmarco_document
 from . import msmarco_document_v2
 from . import msmarco_passage
