@@ -272,7 +272,7 @@ class Gov2DocCountFile:
         if not os.path.exists(self._path):
             docs_urls_path = os.path.join(self._docs_dlc.path(), 'GOV2_extras/url2id.gz')
             result = Counter()
-            with _logger.pbar_raw(desc='building doccounts file', total=25205179) as pbar:
+            with _logger.pbar_raw(desc='building doccounts file', total=25205179, unit='doc') as pbar:
                 with gzip.open(docs_urls_path, 'rt') as fin:
                     for line in fin:
                         url, doc_id = line.rstrip().split()
