@@ -136,6 +136,11 @@ def _init():
         FilteredQueries(subsets['trec-dl-2020'].queries_handler(), dl20_v2_judged),
         subsets['trec-dl-2020'],
     )
+    subsets['trec-dl-2021'] = Dataset(
+        collection,
+        TsvQueries(dlc['trec-dl-2021/queries'], namespace='msmarco', lang='en'),
+        TrecScoredDocs(GzipExtract(dlc['trec-dl-2021/scoreddocs'])),
+    )
 
     ir_datasets.registry.register(NAME, Dataset(collection, documentation("_")))
     for s in sorted(subsets):
