@@ -41,6 +41,8 @@ def _init():
     sources = [
         ('en1k', 369721),
         ('en59k', 2454785),
+        ('en78k', 2454785),
+        ('ens78k', 2454785),
         ('fr14k', 736616),
         ('es13k', 645901),
         ('it16k', 503012),
