@@ -256,11 +256,13 @@ class Lz4PickleTransaction:
 
 
 class PickleLz4FullStore(Docstore):
-    def __init__(self, path, init_iter_fn, data_cls, lookup_field, index_fields, key_field_prefix=None):
+    def __init__(self, path, init_iter_fn, data_cls, lookup_field, index_fields, key_field_prefix=None, size_hint=None, count_hint=None):
         super().__init__(data_cls, lookup_field)
         self.path = path
         self.init_iter_fn = init_iter_fn
         self.lookup = Lz4PickleLookup(path, data_cls, lookup_field, index_fields, key_field_prefix)
+        self.size_hint = size_hint
+        self.count_hint = count_hint
 
     def get_many_iter(self, keys):
         self.build()
@@ -268,8 +270,10 @@ class PickleLz4FullStore(Docstore):
 
     def build(self):
         if not self.built():
+            if self.size_hint:
+                ir_datasets.util.check_disk_free(self.path, self.size_hint)
             with self.lookup.transaction() as trans, _logger.duration('building docstore'):
-                for doc in _logger.pbar(self.init_iter_fn(), 'docs_iter'):
+                for doc in _logger.pbar(self.init_iter_fn(), 'docs_iter', unit='doc', total=self.count_hint):
                     trans.add(doc)
 
     def built(self):
